Write temp tables
temp_table.RdThis function writes temporary tables to the database to improve query efficiency. Temporary tables are automatically removed once the user disconnects from the database.
Arguments
- dbcon
(
DBIConnection)
A database connection to any GEMINI database.- data
(
data.tableordata.frame)
Data table to be written to DB as temp table.- table_name
(
data.tableordata.frame)
Name of temporary table in DB (default = "rgemini_temp_table").- analyze
(
logical)
Whether or not to use SQL Analyze statement to further improve query efficiency (recommended).
Examples
if (FALSE) { # \dontrun{
temp_table(dbcon, data.table(genc_id = c(1, 2, 3)))
} # }